# API reference overview

All of components and classes are grouped in the imported library named `Panoramax`.

## `components.core`

Main web components:

- [Basic](./reference/components/core/Basic.md) : base class for other components, embedding shared logic.
- [CoverageMap](./reference/components/core/CoverageMap.md) : map showing Panoramax data availability.
- [Editor](./reference/components/core/Editor.md) : photo and map display for editing purposes.7
- [PhotoViewer](./reference/components/core/PhotoViewer.md) : the classic photo-only viewer.
- [Viewer](./reference/components/core/Viewer.md) : the photo and map viewer.

## `components.layout`

Layout helpers:

- [BottomDrawer](./reference/components/layout/BottomDrawer.md) : a mobile-like drawer from screen bottom.
- [CorneredGrid](./reference/components/layout/CorneredGrid.md) : corner-oriented layout over a background component.
- [Mini](./reference/components/layout/Mini.md) : reduced and collapsable mini component.
- [Tabs](./reference/components/layout/Tabs.md) : tabbed content manager.

## `components.menus`

All-in-one, ready-to-use menus for complex operations. Note that they don't embed a container (like popup or panel) to be reusable in any situation.

- [AnnotationsList](./reference/components/menus/AnnotationsList.md) : selected picture list of annotations (areas with tags).
- [MapBackground](./reference/components/menus/MapBackground.md) : change map background.
- [MapFilters](./reference/components/menus/MapFilters.md) : set map filters.
- [MapLayers](./reference/components/menus/MapLayers.md) : change map theme and background.
- [MapLegend](./reference/components/menus/MapLegend.md) : display map sources and Panoramax info.
- [PictureLegend](./reference/components/menus/PictureLegend.md) : display date, author and info for a picture.
- [PictureMetadata](./reference/components/menus/PictureMetadata.md) : display full details about a picture.
- [PlayerOptions](./reference/components/menus/PlayerOptions.md) : speed and constrast settings for play sequence feature.
- [QualityScoreDoc](./reference/components/menus/QualityScoreDoc.md) : details about quality score computation.
- [ReportForm](./reference/components/menus/ReportForm.md) : picture issue reporting form.
- [ShareMenu](./reference/components/menus/ShareMenu.md) : links and iframe sharing.

## `components.ui`

Basic UI components:

- [Button](./reference/components/ui/Button.md) : a simple button.
- [ButtonGroup](./reference/components/ui/ButtonGroup.md) : button bar.
- [CopyButton](./reference/components/ui/CopyButton.md) : a copy-to-clipboard button.
- [Grade](./reference/components/ui/Grade.md) : a 5-star rating display.
- [HashTags](./reference/components/ui/HashTags.md) : a list of hashtags associated to a picture.
- [LinkButton](./reference/components/ui/LinkButton.md) : a link button.
- [ListGroup](./reference/components/ui/ListGroup.md) : a menu-like list of buttons and links.
- [ListItem](./reference/components/ui/ListItem.md) : a Material Design-like list entry.
- [Loader](./reference/components/ui/Loader.md) : the fullscreen initial loader.
- [Map](./reference/components/ui/Map.md) : the browseable map (MapLibre GL).
- [MapMore](./reference/components/ui/MapMore.md) : advanced version of the browseable map.
- [Photo](./reference/components/ui/Photo.md) : the picture display (Photo Sphere Viewer).
- [Popup](./reference/components/ui/Popup.md) : an overlaying popup/modal.
- [ProgressBar](./reference/components/ui/ProgressBar.md) : a progress bar.
- [QualityScore](./reference/components/ui/QualityScore.md) : a A/B/C/D/E grade display and input.
- [SearchBar](./reference/components/ui/SearchBar.md) : a search bar.
- [SemanticsTable](./reference/components/ui/SemanticsTable.md) : table for showing complete semantic tags of a picture/annotation.
- [TogglableGroup](./reference/components/ui/TogglableGroup.md) : an helper for showing a menu on button click.


## `components.ui.widgets`

More complex UI components (but not menus):

- [CopyCoordinates](./reference/components/ui/widgets/CopyCoordinates.md) : a copy-to-clipboard button for coordinates, with many format options.
- [GeoSearch](./reference/components/ui/widgets/GeoSearch.md) : a geocoder search bar with GPS location tool.
- [Legend](./reference/components/ui/widgets/Legend.md) : a togglable map/picture legend.
- [MapFiltersButton](./reference/components/ui/widgets/MapFiltersButton.md) : a togglable map filters button & menu.
- [MapLayersButton](./reference/components/ui/widgets/MapLayersButton.md) : a togglable map layers button & menu.
- [OSMEditors](./reference/components/ui/widgets/OSMEditors.md) : shortcuts for OpenStreetMap editing tools.
- [PictureLegendActions](./reference/components/ui/widgets/PictureLegendActions.md) : various actions from picture legend.
- [Player](./reference/components/ui/widgets/Player.md) : the previous/next/play/pause toolbar.
- [Zoom](./reference/components/ui/widgets/Zoom.md) : the +/- zoom toolbar.

## `utils`

General helpers outside of single component scope:

- [API](./reference/utils/API.md) : the Panoramax API helper (many get & post HTTP helpers).
- [InitParameters](./reference/utils/InitParameters.md) : helper for merging URL and component parameters.
- [URLHandler](./reference/utils/URLHandler.md) : the window URL manager (changes query part).
